

Azure
=====

.. autopydantic_model:: rohmu.object_storage.config.AzureObjectStorageConfig

.. autoclass:: rohmu.object_storage.azure.AzureTransfer
   :members:


Google
======

.. autopydantic_model:: rohmu.object_storage.config.GoogleObjectStorageConfig

.. autoclass:: rohmu.object_storage.google.GoogleTransfer
   :members:

.. autoclass:: rohmu.object_storage.google.MediaStreamUpload
   :members:

.. autoclass:: rohmu.object_storage.google.MediaIoBaseDownloadWithByteRange
   :members:


Local
=====

.. autopydantic_model:: rohmu.object_storage.config.LocalObjectStorageConfig

.. autoclass:: rohmu.object_storage.local.LocalTransfer
   :members:


S3
==

.. autopydantic_model:: rohmu.object_storage.config.S3ObjectStorageConfig

.. autoclass:: rohmu.object_storage.s3.S3Transfer
   :members:


SFTP
====

.. autopydantic_model:: rohmu.object_storage.config.SFTPObjectStorageConfig

.. autoclass:: rohmu.object_storage.sftp.SFTPTransfer
   :members:


Swift
=====

.. autopydantic_model:: rohmu.object_storage.config.SwiftObjectStorageConfig

.. autoclass:: rohmu.object_storage.swift.SwiftTransfer
   :members:
